@@ -1,6 +1,6 @@
-# import sys, os
-# SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
-# sys.path.append(SCRIPT_DIR)
+import sys, os
+SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(SCRIPT_DIR)
 
 from globals import *
 # contains helper functions used in parser.py
